#!/usr/local/bin/perl

use strict;
use vars qw($opt_r @range);
use Getopt::Std;
use GD;

getopt('r'); # one argument for range

if($opt_r) {
    (@range) = split(/:/, $opt_r); # arguments must resemble first:last
                                   # or output the usage message for error
    if($#range+1 == 2) {
	&make_image($range[0], $range[1]); # now, output images from
                                           # first to last
    } else {
	&usage(); # fail-case.  output usage message
    }
} else {
    &usage(); # fail-case.  output usage message
}

sub make_image {

    my($first, $last) = @_; # pass-in first, last gif numbers
    my($im, $white, $black, $width, $height);

    for ($first .. $last) {
	
	# Compute the ratio of $width, $height to the font (8x16 - large)
	$width = length($_)*8; # Single digits = 8, double = 16, etc.
	$height = 16; # the height will always be 16 for the large font

	# output all gifs to the Images directory.  Change this per your spec
	open(OUTFILE, ">"."Images/".$_.".gif") 
	    || die("output file error: $!");
	print("Opening: $_.gif for writing.\n");

	$im = new GD::Image($width, $height);
	($white,$black) = 
	    (
	     $im->colorAllocate(255, 255, 255),
	     $im->colorAllocate(0, 0, 0)
	     );
	$im->transparent($white);	# white color is transparent
	$im->interlaced(1);		# cool venetian blinds effect
	
	$im->string(gdLargeFont,0,0,$_,$black); # use the 8x16 font
	
	print OUTFILE $im->gif; # output the image to (FILEHANDLE)
	close(OUTFILE);
    }
}


sub usage {
    print("Usage: $0 -r <first:last>\n");
    exit(0); # failure
}
