#!/usr/local/bin/perl -w

use Getopt::Long;
use Net::SMTP;
use vars qw($result $opt_f $opt_t $opt_host);
use strict;

my($smtp, $lines);
my(@message_body, @recipients);

GetOptions qw(-f=s -t=s --host=s);

if($opt_f && $opt_t) { # both options have been entered - proceed.
    chop($opt_host = `hostname`) unless $opt_host; # localhost is default
    $smtp = Net::SMTP->new($opt_host, Timeout => 60); # constructor

    $smtp->mail($opt_f); # message sender
    @recipients = split(/\,/, $opt_t); # parse multiple recipients
    if($#recipients+1 == 1) { # single recipient only
	$smtp->to($opt_t); 
    } else { # multiple recipients
	foreach (@recipients) { $smtp->to($_); } # send multiple RCPT 
	                                         # commands to sendmail
    }

    @message_body = <>;
    $lines = join("", @message_body);

    $smtp->data();
    $smtp->datasend(<<DATA);
To: $opt_t
Subject: $0

$lines

DATA


    $smtp->dataend();
    $smtp->quit;
} else { # something's wrong with the command-line options - error.
    &usage();
}

sub usage {
    print("Usage: $0 -f <from> -t <recipient> -host <hostname> <STDIN>\n");
    exit(0); # failure
}
