#!/usr/local/bin/perl -w

use strict;
use Tk;
use Tk::JPEG;
use Getopt::Long;

my($main, $left, $right);
my($image, $im_l, $im_type, $image_file);
my($i_name);
my($file_sel, $top, $text, $fname, $btm);
my($b1, $b2, $b3);

# Default image which gets loaded when there is not a command-line argument
my $earth = '/usr/local/lib/perl5/site_perl/Tk/demos/images/earth.gif';

# Get the command-line arguments.
# Switches: image, help.  Image takes one argument - help calls subroutine help
GetOptions('image:s', \$i_name, 'help:s', \&help);

$main = new MainWindow;

$left = $main->Frame(-relief => 'sunken', -borderwidth => 3);

if($i_name) {
    $i_name =~ /(.+)\.(.+)/;
    if(($im_type = check_image_format($2)) eq '') {
	print("Image format not supported.\n");
	exit(0);
    }
    $image = $left->Photo('-format' => $im_type,
			  -file => $i_name);
} else {
    $image = $left->Photo('-format' => $im_type,
			  -file => $earth);
}
    $im_l = $left->Label('-image' => $image);
    $im_l->pack(-expand => 1, -fill => 'both');

$left->pack(-expand => 1, -fill => 'both', -side => 'left');


$right = $main->Frame();
$right->Button(-text => 'Open Image', -command => sub {
    
    $file_sel = $main->Toplevel(-title => 'Select a file');
    $top = $file_sel->Frame();
    $text = $top->Label(-text => 'Filename: ');
    $text->pack(-expand => 1, -fill => 'both', -side => 'left');
    $fname = $top->Entry();
    $fname->pack(-expand => 1, -fill => 'both', -side => 'left');
    $top->pack(-expand => 1, -fill => 'both');
    
    $btm = $file_sel->Frame();
    $b1 = $btm->Button(-text => 'Open', -command => sub {
	$image_file = $fname->get;
	if(-f $image_file) {
	    print("Loading: $image_file\n");
	    $image->delete;
	    $im_l->pack('forget');

	    $image_file =~ /(.+)\.(.+)/;
	    if(($im_type = check_image_format($2)) eq '') {
		print("Image format not supported.\n");
		exit(0);
	    }
	    $image = $left->Photo('-format' => $im_type,
				  -file => $image_file);
	    $im_l = $left->Label('-image' => $image);
	    $im_l->pack(-expand => 1, -fill => 'both');

	    $file_sel->withdraw;
	} else {
	    # Error, man.
	    print("Cannot load file.\n");
	}
    });
    $b1->pack(-side => 'left');
    $b2 = $btm->Button(-text => 'Cancel',
		       -command => [$file_sel=>'withdraw']);
    $b2->pack(-side => 'left');
    $b3 = $btm->Button(-text => 'Quit', -command => sub{exit});
    $b3->pack(-side => 'left');
    $btm->pack(-expand => 1, -fill => 'both');
})->pack(-expand => 1, -fill => 'both');

$right->Button(-text => 'Close Image',
	      -command => sub { $image->delete; })->pack(-expand => 1, 
							 -fill => 'both');
$right->Button(-text => 'Exit Program', 
	       -command => sub{$image->delete; exit})->pack(-expand => 1, 
							    -fill => 'both');
$right->pack(-expand => 1, -fill => 'both', -side => 'right');


# THE MAIN EVENT
MainLoop;

# Helper functions

sub help {
    print("Usage: showimage.pl -image <imagename>\n");
    print("                    -help\n");
    print("                    -noarg (default)\n");
    exit(0);
}

sub check_image_format {
    my($ext) = @_;
    my(%TYPES) = ();

    %TYPES = ( 'jpg' => 'jpeg', 'gif' => 'gif');

    foreach (keys %TYPES) { 
	if($ext eq $_) { return($TYPES{$_}); } 
    }
}
